import tkinter as tk
from tkinterdnd2 import DND_FILES, TkinterDnD

def replace_and_save(input_file_path, output_file_path):
    # 置換ルールを定義
    replacement_rules = {
        '①': '(1)',
        '②': '(2)',
        '③': '(3)',
        '④': '(4)',
        '⑤': '(5)',
        '⑥': '(6)',
        '⑦': '(7)',
        '⑧': '(8)',
        '⑨': '(9)',
        '⑩': '(10)',
        '⑪': '(11)',
        '⑫': '(12)',
        '⑬': '(13)',
        '⑭': '(14)',
        '⑮': '(15)',
        '⑯': '(16)',
        '⑰': '(17)',
        '⑱': '(18)',
        '⑲': '(19)',
        '⑳': '(20)',
        # 他の置換ルールも追加できます
    }
    
    try:
        with open(input_file_path, 'r', encoding='utf-8') as input_file:
            # ファイル内容を読み込み、置換を行う
            content = input_file.read()
            for old, new in replacement_rules.items():
                content = content.replace(old, new)

        # 置換後の内容を新しいファイルに書き込み
        with open(output_file_path, 'w', encoding='utf-8') as output_file:
            output_file.write(content)

        print(f'ファイルが置換されて {output_file_path} に保存されました。')
    except FileNotFoundError:
        print(f'指定されたファイル {input_file_path} が見つかりません。')
    except Exception as e:
        print('エラーが発生しました: {}'.format(str(e)))

def drop(event):
    # ドロップされたファイルのパスを取得
    input_file_path = event.data
    output_file_path = input_file_path.replace('.txt', '_output.txt')
    replace_and_save(input_file_path, output_file_path)

app = TkinterDnD.Tk()

# ドロップを受け入れるラベル
label = tk.Label(app, text="テキストファイルをここにドロップしてください")
label.pack(padx=20, pady=20)

# ドロップ操作を処理するコールバックを設定
app.drop_target_register(DND_FILES)
app.dnd_bind('<<Drop>>', drop)

app.mainloop()
